@@ -34,6 +34,8 @@
 #include "gtkprivate.h"
 #include "gtktypebuiltins.h"
 #include "gtkwindow.h"
+#include "gtkicontheme.h"
+#include "gtkstock.h"
 #include "gtkalias.h"
 
 static void gtk_builder_class_init     (GtkBuilderClass *klass);
@@ -68,6 +70,7 @@ struct _GtkBuilderPrivate
   GSList *signals;
   gchar *current_root;
   GSList *root_objects;
+  gchar *filename;
 };
 
 G_DEFINE_TYPE (GtkBuilder, gtk_builder, G_TYPE_OBJECT)
@@ -139,6 +142,7 @@ gtk_builder_finalize (GObject *object)
   g_hash_table_destroy (builder->priv->objects);
   g_slist_foreach (builder->priv->root_objects, (GFunc)g_object_unref, NULL);
   g_slist_free (builder->priv->root_objects);
+  g_free (builder->priv->filename);
 }
 
 static void
@@ -286,7 +290,8 @@ gtk_builder_get_parameters (GtkBuilder  *builder,
 
       parameter.name = prop->name;
 
-      if (G_IS_PARAM_SPEC_OBJECT (pspec))
+      if (G_IS_PARAM_SPEC_OBJECT (pspec) &&
+          (G_PARAM_SPEC_VALUE_TYPE (pspec) != GDK_TYPE_PIXBUF))
         {
           if (pspec->flags & G_PARAM_CONSTRUCT_ONLY)
             {
@@ -620,7 +625,7 @@ gtk_builder_new (void)
  * @filename: the name of the file to parse
  * @error: return location for an error, or %NULL
  *
- * Parses a string containing a <link linkend="BUILDER-UI">GtkBuilder 
+ * Parses a file containing a <link linkend="BUILDER-UI">GtkBuilder 
  * UI definition</link> and merges it with the current contents of @builder. 
  * 
  * Returns: A positive value on success, 0 if an error occurred
@@ -647,6 +652,8 @@ gtk_builder_add_from_file (GtkBuilder   *builder,
       return 0;
     }
   
+  builder->priv->filename = g_strdup (filename);
+
   _gtk_builder_parser_parse_buffer (builder, filename,
                                     buffer, length,
                                     &tmp_error);
@@ -689,6 +696,8 @@ gtk_builder_add_from_string (GtkBuilder   *builder,
 
   tmp_error = NULL;
 
+  builder->priv->filename = g_strdup (".");
+
   _gtk_builder_parser_parse_buffer (builder, "<input>",
                                     buffer, length,
                                     &tmp_error);
@@ -1170,34 +1179,65 @@ gtk_builder_value_from_string_type (GtkBuilder   *builder,
         ret = FALSE;
       break;
     case G_TYPE_OBJECT:
-#if 0
-        if (G_VALUE_HOLDS (value, GDK_TYPE_PIXBUF))
-      {
-        gchar *filename;
-        GError *tmp_error = NULL;
-        GdkPixbuf *pixbuf;
+      if (G_VALUE_HOLDS (value, GDK_TYPE_PIXBUF))
+        {
+          gchar *filename;
+          GError *tmp_error = NULL;
+          GdkPixbuf *pixbuf;
+       
+          if (gtk_builder_get_object (builder, string))
+            {
+              g_set_error (error,
+                           GTK_BUILDER_ERROR,
+                           GTK_BUILDER_ERROR_INVALID_VALUE,
+                           "Could not load image '%s': "
+                           " '%s' is already used as object id",
+                           string, string);
+              return FALSE;
+            }
 
-        filename = gtk_xml_relative_file (xml, string);
-        pixbuf = gdk_pixbuf_new_from_file (filename, &tmp_error);
-        if (pixbuf)
-          {
-            g_value_set_object (value, pixbuf);
-            g_object_unref (G_OBJECT (pixbuf));
-          }
-        else
-          {
-	    g_set_error (error,
-			 GTK_BUILDER_ERROR,
-			 GTK_BUILDER_ERROR_INVALID_VALUE,
-			 "could not load image `%s'",
-			 tmp_error->message);
-            g_error_free (tmp_error);
-            ret = FALSE;
-          }
-        g_free (filename);
-      }
-        else
-#endif
+          if (g_path_is_absolute (string))
+            filename = g_strdup (string);
+          else
+            {
+              gchar *dirname;
+
+              dirname = g_path_get_dirname (builder->priv->filename);
+              filename = g_build_filename (dirname, string, NULL);
+
+              g_free (dirname);
+            }
+
+          pixbuf = gdk_pixbuf_new_from_file (filename, &tmp_error);
+
+          if (pixbuf == NULL)
+            {
+              GtkIconTheme *theme;
+
+              g_warning ("Could not load image '%s': %s", 
+                         string, tmp_error->message);
+              g_error_free (tmp_error);
+
+              /* fall back to a missing image */
+              theme = gtk_icon_theme_get_default ();
+              pixbuf = gtk_icon_theme_load_icon (theme, 
+                                                 GTK_STOCK_MISSING_IMAGE,
+                                                 16,
+                                                 GTK_ICON_LOOKUP_USE_BUILTIN,
+                                                 NULL);
+            }
+ 
+          if (pixbuf)
+            {
+              g_value_set_object (value, pixbuf);
+              g_object_unref (G_OBJECT (pixbuf));
+            }
+
+          g_free (filename);
+
+          ret = TRUE;
+        }
+      else
         ret = FALSE;
       break;
     default:
@@ -1366,7 +1406,7 @@ _gtk_builder_flags_from_string (GType         type,
  * Returns: the #GType found for @type_name or #G_TYPE_INVALID 
  *   if no type was found
  *
- * Since 2.12
+ * Since: 2.12
  */
 GType
 gtk_builder_get_type_from_name (GtkBuilder  *builder, 
