@@ -1635,9 +1635,6 @@ gtk_entry_completion_real_insert_prefix (GtkEntryCompletion *completion,
       key = gtk_entry_get_text (GTK_ENTRY (completion->priv->entry));
       key_len = g_utf8_strlen (key, -1);
 
-      if (completion->priv->completion_prefix == NULL)
-        completion->priv->completion_prefix = g_strdup (key);
-
       if (prefix_len > key_len)
 	{
 	  gint pos = prefix_len;
@@ -1688,9 +1685,6 @@ gtk_entry_completion_insert_completion_text (GtkEntryCompletion *completion,
   if (priv->insert_text_id > 0)
     g_signal_handler_block (priv->entry, priv->insert_text_id);
 
-  if (completion->priv->completion_prefix == NULL)
-    completion->priv->completion_prefix = g_strdup (gtk_entry_get_text (GTK_ENTRY (priv->entry)));
-
   gtk_entry_set_text (GTK_ENTRY (priv->entry), text);
 
   len = strlen (priv->completion_prefix);
