@@ -125,6 +125,7 @@ enum
   PROP_SIZE
 };
 
+static void           gtk_recent_manager_dispose      (GObject               *object);
 static void           gtk_recent_manager_finalize     (GObject               *object);
 
 static void           gtk_recent_manager_set_property (GObject               *object,
@@ -232,6 +233,7 @@ gtk_recent_manager_class_init (GtkRecentManagerClass *klass)
   
   gobject_class->set_property = gtk_recent_manager_set_property;
   gobject_class->get_property = gtk_recent_manager_get_property;
+  gobject_class->dispose = gtk_recent_manager_dispose;
   gobject_class->finalize = gtk_recent_manager_finalize;
   
   /**
@@ -387,22 +389,32 @@ gtk_recent_manager_get_property (GObject               *object,
     }
 } 
 
+static void
+gtk_recent_manager_dispose (GObject *object)
+{
+  GtkRecentManager *manager = GTK_RECENT_MANAGER (object);
+  GtkRecentManagerPrivate *priv = manager->priv;
+
+  if (priv->poll_timeout)
+    {
+      g_source_remove (priv->poll_timeout);
+      priv->poll_timeout = 0;
+    }
+
+  G_OBJECT_CLASS (gtk_recent_manager_parent_class)->dispose (object);
+}
+
 static void
 gtk_recent_manager_finalize (GObject *object)
 {
   GtkRecentManager *manager = GTK_RECENT_MANAGER (object);
   GtkRecentManagerPrivate *priv = manager->priv;
 
-  /* remove the poll timeout */
-  if (priv->poll_timeout)
-    g_source_remove (priv->poll_timeout);
-  
   g_free (priv->filename);
   
   if (priv->recent_items)
     g_bookmark_file_free (priv->recent_items);
 
-  /* chain up parent's finalize method */  
   G_OBJECT_CLASS (gtk_recent_manager_parent_class)->finalize (object);
 }
 
@@ -435,10 +447,7 @@ gtk_recent_manager_real_changed (GtkRecentManager *manager)
 	}
 
       write_error = NULL;
-      g_bookmark_file_to_file (priv->recent_items,
-		               priv->filename,
-			       &write_error);
-
+      g_bookmark_file_to_file (priv->recent_items, priv->filename, &write_error);
       if (write_error)
         {
           filename_warning ("Attempting to store changes into `%s', "
@@ -513,7 +522,7 @@ gtk_recent_manager_poll_timeout (gpointer data)
       return TRUE;
     }
 
-  /* the file didn't change from the last poll(), so we bail out */
+  /* the file didn't change from the last poll, so we bail out */
   if (stat_buf.st_mtime == priv->last_mtime)
     return TRUE;
 
@@ -709,7 +718,7 @@ gtk_recent_manager_get_default (void)
  *   and can be used as long as the screen is open. Do not ref or
  *   unref it.
  *
- * @Deprecated: 2.12: This function has been deprecated and should
+ * Deprecated: 2.12: This function has been deprecated and should
  *   not be used in newly written code. Calling this function is
  *   equivalent to calling gtk_recent_manager_get_default().
  *
@@ -732,7 +741,7 @@ gtk_recent_manager_get_for_screen (GdkScreen *screen)
  * 
  * Since: 2.10
  *
- * @Deprecated: 2.12: This function has been deprecated and should
+ * Deprecated: 2.12: This function has been deprecated and should
  *   not be used in newly written code. Calling this function has
  *   no effect.
  */
@@ -796,11 +805,11 @@ gtk_recent_manager_get_limit (GtkRecentManager *manager)
  * Adds a new resource, pointed by @uri, into the recently used
  * resources list.
  *
- * This function automatically retrieving some of the needed
+ * This function automatically retrieves some of the needed
  * metadata and setting other metadata to common default values; it
  * then feeds the data to gtk_recent_manager_add_full().
  *
- * See gtk_recent_manager_add_full() if you want to explicitely
+ * See gtk_recent_manager_add_full() if you want to explicitly
  * define the metadata for the resource pointed by @uri.
  *
  * Return value: %TRUE if the new item was successfully added
@@ -2136,7 +2145,7 @@ get_uri_shortname_for_display (const gchar *uri)
       rest = get_method_string (uri, &method);
       local_file = g_filename_display_basename (rest);
       
-      name = g_strdup_printf ("%s: %s", method, local_file);
+      name = g_strconcat (method, ": ", local_file, NULL);
       
       g_free (local_file);
       g_free (method);
